<template>
  <div class="full-page bg" element-loading-text="数据加载中..." element-loading-spinner="el-icon-loading"
    element-loading-background="rgba(255,255,255, 0.5)" v-loading.fullscreen.lock="markLoading">
    <div class="search-container">
      <el-form ref="form" :model="searchForm" label-width="auto">
        <el-row :gutter="20">
          <el-col :span="5">
            <el-form-item label="项目名称">
              <el-input v-model="searchForm['p.PROJECT_NAME_']" clearable placeholder="请输入项目名称"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="所属领域">
              <dict-select dictCode="ggbb_ssly" :hasDefaultOption="true" clearable
                v-model="searchForm['p.PROJECT_FIELD_']" style="width: 100%"
                @select="(val, obj) => hanldeCommonSelect(val, obj, 'form')" placeholder="请选择所属领域" />
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="所属跑道">
              <el-select v-model="searchForm['p.PROJECT_RUNWAY_']" style="width: 100%" clearable placeholder="请选择所属跑道">
                <el-option v-for="item in demandRunwaOoptionsForm" :key="item.value" :label="item.name"
                  :value="item.value">
                </el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="牵头市领导" prop="label">
              <el-input v-model="searchForm['p.LEADER_']" clearable placeholder="请输入牵头市领导"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="2">
            <el-button icon="el-icon-search" type="primary" class="btn btn-plus" @click="handleSearch">
              {{ this.$t('common.search') }}
            </el-button>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <el-row :gutter="10" class="main-table-container flex">
      <el-col :span="24" class="table-container" ref="contentPanel" style="padding: 20px">
        <div style="margin-bottom: 10px" ref="btnPanel"></div>
        <div :style="{ width: '100%', height: `${tableMaxHeight}` + 'px' }">
          <el-table stripe size="mini" v-loading="tableLoading" ref="multipleSelection" :data="tableData"
            :max-height="tableMaxHeight" :style="{
              width: '100%',
              height: `${tableMaxHeight}` + 'px'
            }" @selection-change="handleSelectionChange">
            <!-- <el-table-column
              type="selection"
              width="55"
              align="center"
            ></el-table-column> -->
            <el-table-column type="index" width="55" label="序号" align="center">
            </el-table-column>
            <el-table-column prop="projectName" show-overflow-tooltip min-width="200" align="center" label="项目名称">
            </el-table-column>
            <el-table-column prop="leader" show-overflow-tooltip min-width="80" align="center" label="牵头市领导">
              <!-- <template v-slot="{row}">
                {{ getDictName('ggbb_sspd', row.leader) }}
              </template> -->
            </el-table-column>
            <el-table-column prop="projectField" show-overflow-tooltip min-width="80" align="center" label="所属领域">
              <template v-slot="{ row }">
                {{ getDictName('ggbb_ssly', row.projectField) }}
              </template>
            </el-table-column>
            <el-table-column prop="projectRunway" show-overflow-tooltip width="100" align="center" label="所属跑道">
              <template v-slot="{ row }">
                {{ getDictName('ggbb_sspd', row.projectRunway) }}
              </template>
            </el-table-column>
            <el-table-column prop="unitName" show-overflow-tooltip min-width="100" align="center" label="责任单位">
            </el-table-column>
            <el-table-column prop="propulsiveStatus" show-overflow-tooltip width="130" align="center" label="审核状态">
              <template v-slot="{ row }">
                <el-tag type="info" v-if="!row.status && row.status != 0">待录入</el-tag>
                <status-by-color v-else :status="row.status" />
              </template>
            </el-table-column>
            <el-table-column show-overflow-tooltip width="160" align="center" fixed="right" label="操作">
              <template v-slot="{ row }">
                <el-link v-if="row.status == 0" icon="el-icon-s-check" type="primary" :underline="false"
                  class="cloumn-btn updata-btn" @click="handleAppear(row, 1)">
                  上报
                </el-link>
                <el-link icon="el-icon-s-check" type="danger" :underline="false" class="cloumn-btn wait-updata-btn"
                  v-if="!row.status && row.status != 0" @click="handleAdd(row)">
                  待更新
                </el-link>
                <el-link v-if="row.status == 0" icon="el-icon-edit" type="primary" :underline="false"
                  class="cloumn-btn updata-btn" @click="handleEdit(row)">
                  编辑
                </el-link>
                <el-link v-if="row.status == 2 || row.status == 4 || row.status == 5" icon="el-icon-s-check"
                  type="primary" :underline="false" class="cloumn-btn updata-btn" @click="handleUpdate(row)">
                  更新
                </el-link>
                <el-link icon="el-icon-view" type="primary" :underline="false" class="cloumn-btn updata-btn"
                  v-if="row.status == 1 || row.status == 3 || row.status == 5" @click="handleLookDetiles(row)">
                  详情
                </el-link>
                <el-link v-if="row.status == 1" icon="el-icon-refresh-left" type="danger" :underline="false"
                  class="cloumn-btn withdraw" @click="handleAppear(row, 0)">
                  撤回
                </el-link>
              </template>
            </el-table-column>
          </el-table>
        </div>
        <pagination ref="paginationPanel" style="margin-top: 10px" :pageResult="pageResult"
          @size-change="handleSizeChange" @current-change="handleCurrentChange" />
      </el-col>
    </el-row>
    <!-- 弹层 -->
    <BrandDisplayForm ref="BrandDisplayForm" @flushed="flushed"></BrandDisplayForm>
    <BrandDisplayDetails ref="BrandDisplayDetails"></BrandDisplayDetails>
  </div>
</template>

<script>
import pagination from '@/components/pagination'
import { TableMixin } from '@/mixins/tableMixin'
import brand from '@/api/MajorReformProjects/brandDisplay'
import BrandDisplayForm from './dialog/BrandDisplayForm.vue'
import BrandDisplayDetails from './dialog/BrandDisplayDetails.vue'
export default {
  name: 'BrandDisplayUpdate',
  components: {
    pagination,
    BrandDisplayForm,
    BrandDisplayDetails
  },
  mixins: [TableMixin],
  data() {
    return {
      markLoading: false,
      tableMaxHeight: 400,
      loading: false,
      tableLoading: false,
      tableData: [],
      multipleSelection: [],
      total: 0,
      params: {
        pageBean: {
          page: 1,
          pageSize: 20
          // total: 0
        }
      },
      pageResult: {
        page: 1,
        pageSize: 20,
        total: 0
      },
      searchForm: {}, // 顶部搜索对象
      deleteIds: '', // 是否选中列表解锁删除按钮
      activeCollapse1: ['1', '2', '3']
    }
  },

  created() {
    this.loadData(this.params)
  },
  methods: {
    //获取数据
    loadData(params) {
      this.tableLoading = true
      brand.getTableData(params, false, res => {
        this.pageResult.total = res.total
        this.tableData = res.rows
        this.tableLoading = false
      })
    },
    handleEdit(row) {
      this.$refs.BrandDisplayForm.isUpdate = true
      this.$refs.BrandDisplayForm.title = '编辑'
      this.$refs.BrandDisplayForm.openForm(row)
    },
    flushed() {
      this.loadData(this.params)
    },
    //添加
    handleAdd(row) {
      this.$refs.BrandDisplayForm.isUpdate = false
      this.$refs.BrandDisplayForm.title = '更新'
      this.$refs.BrandDisplayForm.openForm(row)
    },
    //更新
    handleUpdate(row) {
      this.$refs.BrandDisplayForm.isUpdate = false
      this.$refs.BrandDisplayForm.title = '更新'
      this.$refs.BrandDisplayForm.openForm(row)
    },
    handleLookDetiles(row) {
      this.$refs.BrandDisplayDetails.open(row)
    },
    // 删除
    handleDelete(id) { },
    // 撤回
    handleWithdraw() {

    },
    // 上报
    handleAppear(row, status) {
      let msg = status ? '上报' : '撤回'
      this.$confirm(`确认${msg}吗？`, this.$t('common.tips'), {
        confirmButtonText: this.$t('common.confirm'),
        cancelButtonText: this.$t('common.cancel'),
        type: status ? 'success' : 'error'
      }).then(() => {
        this.markLoading = true
        let data = {
          status,
          id: row.id
        }
        if (!status) {
          data.approvalResults = 2
        }
        brand.updateStatusById(data, res => {
          if (res.state) {
            this.markLoading = false
            row.status = status
            this.$message.success(`${msg}成功`)
          }
        })
      })
    },
    // 顶部搜索
    handleSearch() {
      this.tableLoading = true
      let data = JSON.parse(JSON.stringify(this.params))
      let obj = JSON.parse(JSON.stringify(this.searchForm))
      let querys = []
      for (let i in obj) {
        if (obj[i]) {
          querys.push({
            group: 'main',
            operation:
              i == 'p.PROJECT_NAME_' || i == 'p.LEADER_' ? 'LIKE' : 'EQUAL',
            parentGroup: '',
            property: i,
            relation: 'AND',
            value: obj[i]
          })
        }
      }
      data.querys = querys
      this.loadData(data)
    },
    // 弹层关闭
    handleSelectionChange(currentData) {
      if (currentData.length === 0) return (this.deleteIds = '')
      let ids = []
      currentData.forEach(item => {
        ids.push(item.id)
      })
      this.deleteIds = ids.join(',')
    },
    handleCurrentChange(page) {
      this.params.pageBean.page = page
      this.loadData(this.params)
    },
    handleSizeChange(pageSize) {
      this.params.pageBean.pageSize = pageSize
      this.loadData(this.params)
    }
  }
}
</script>

<style lang="scss" scoped>
.common-tree-container {
  height: calc(100% - 70px);
  margin-top: 0.52083vw;
  padding: 1.04167vw 1.04167vw;
  background-color: #fff;
  position: relative;
  box-sizing: border-box;
  overflow-y: auto;
  border-radius: 20px;
  box-shadow: 0px 0px 0.625vw 0 rgba(92, 102, 83, 0.2);
}

.container-head {
  display: flex;
  align-items: center;

  i {
    font-size: 16px;
    margin-left: 5px;
    font-weight: 600;
    cursor: pointer;
  }
}

.move-tree /deep/ .el-tree {
  height: 90%;
  overflow-y: auto;
  border: none;
}

.cloumn-btn {
  border: 1px solid #2761ff;
  padding: 3px 10px;
  border-radius: 5px;

  &:nth-child(1),
  &:nth-child(2),
  &:nth-child(3) {
    margin-right: 5px;
  }

  // &:nth-child(1):hover {
  //   background-color: #2761ff;
  //   color: #fff;
  // }
  // &:nth-child(2):hover {
  //   background-color: #2761ff;
  //   color: #fff;
  // }
  // &:nth-child(3):hover {
  //   background-color: #f56c6c;
  //   color: #fff;
  //   border-color: #f56c6c;
  // }
  // &:nth-child(4):hover {
  //   background-color: #2761ff;
  //   color: #fff;
  // }
  .del {
    border: 1px solid #f56c6c;
  }

  /deep/ i,
  span {
    font-size: 16px;
  }
}

.wait-updata-btn {
  border: 1px solid #f56c6c;

  &:hover {
    background-color: #f56c6c;
    color: #fff;
    border-color: #f56c6c;
  }
}

.updata-btn {
  border: 1px solid #2761ff;

  &:hover {
    background-color: #2761ff;
    color: #fff;
    border-color: #2761ff;
  }
}

.descriptions-btn {
  &:hover {
    background-color: #2761ff;
    color: #fff;
    border-color: #2761ff;
  }
}

/deep/ .el-tree-node__content {
  padding: 5px 0;
}

.upload_file {
  opacity: 1;
  pointer-events: auto;
  transition: opacity 0.3s;
}

.upload_file_none {
  opacity: 0;
  pointer-events: none;
  transition: opacity 0.3s;
}
</style>
